
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

            #include <glib-object.h>


            G_BEGIN_DECLS

/* enumerations from "lfb-event.h" */


GType lfb_event_state_get_type (void);
#define LFB_TYPE_EVENT_STATE (lfb_event_state_get_type())


GType lfb_event_end_reason_get_type (void);
#define LFB_TYPE_EVENT_END_REASON (lfb_event_end_reason_get_type())

G_END_DECLS

/* Generated data ends here */

